@@ -1,5 +1,3 @@
-context("Plotting US maps")
-
 test_that("dependencies are verified", {
   expect_package_error("ggplot2", plot_usmap())
 })
@@ -12,7 +10,7 @@ example_data <- data.frame(
 )
 
 p <- plot_usmap("counties", fill = "red")
-q <- plot_usmap(data = statepop, values = "pop_2015", color = "blue")
+q <- plot_usmap(data = statepop, values = "pop_2022", color = "blue")
 r <- plot_usmap(data = example_data, linewidth = 0.8)
 s <- plot_usmap(include = c("AL", "FL", "GA"), labels = TRUE, label_color = "blue")
 t <- plot_usmap("county", include = "AZ", labels = TRUE, fill = "yellow", linewidth = 0.6)
@@ -20,13 +18,13 @@ u <- plot_usmap(include = .new_england, exclude = "ME", labels = TRUE)
 v <- plot_usmap("state", labels = TRUE)
 
 test_that("ggplot object is returned", {
-  expect_is(p, "ggplot")
-  expect_is(q, "ggplot")
-  expect_is(r, "ggplot")
-  expect_is(s, "ggplot")
-  expect_is(t, "ggplot")
-  expect_is(u, "ggplot")
-  expect_is(v, "ggplot")
+  expect_s3_class(p, "ggplot")
+  expect_s3_class(q, "ggplot")
+  expect_s3_class(r, "ggplot")
+  expect_s3_class(s, "ggplot")
+  expect_s3_class(t, "ggplot")
+  expect_s3_class(u, "ggplot")
+  expect_s3_class(v, "ggplot")
 })
 
 test_that("no warnings are produced", {
@@ -43,7 +41,7 @@ test_that("correct data is used", {
   p_map_data <- us_map(regions = "counties")
   expect_identical(p$data, p_map_data)
 
-  q_map_data <- map_with_data(statepop, values = "pop_2015")
+  q_map_data <- map_with_data(statepop, values = "pop_2022")
   expect_identical(q$data, q_map_data)
 
   r_map_data <- map_with_data(example_data)
@@ -80,60 +78,60 @@ test_that("plots are stable", {
 })
 
 test_that("layer parameters are correct", {
-  expect_is(p$layers[[1]], "ggproto")
-  expect_is(p$layers[[1]]$geom, "GeomSf")
+  expect_s3_class(p$layers[[1]], "ggproto")
+  expect_s3_class(p$layers[[1]]$geom, "GeomSf")
   expect_equal(as.character(p$layers[[1]]$aes_params$colour), "black")
   expect_equal(as.character(p$layers[[1]]$aes_params$fill), "red")
   expect_equal(p$layers[[1]]$aes_params$linewidth, 0.4)
 
-  expect_is(q$layers[[1]], "ggproto")
-  expect_is(q$layers[[1]]$geom, "GeomSf")
-  expect_equal(deparse(q$layers[[1]]$mapping$fill), "~.data[[\"pop_2015\"]]")
+  expect_s3_class(q$layers[[1]], "ggproto")
+  expect_s3_class(q$layers[[1]]$geom, "GeomSf")
+  expect_equal(deparse(q$layers[[1]]$mapping$fill), "~.data[[\"pop_2022\"]]")
   expect_equal(as.character(q$layers[[1]]$aes_params$colour), "blue")
   expect_equal(q$layers[[1]]$aes_params$linewidth, 0.4)
 
-  expect_is(r$layers[[1]], "ggproto")
-  expect_is(r$layers[[1]]$geom, "GeomSf")
+  expect_s3_class(r$layers[[1]], "ggproto")
+  expect_s3_class(r$layers[[1]]$geom, "GeomSf")
   expect_equal(deparse(r$layers[[1]]$mapping$fill), "~.data[[\"values\"]]")
   expect_equal(as.character(r$layers[[1]]$aes_params$colour), "black")
   expect_equal(r$layers[[1]]$aes_params$linewidth, 0.8)
 
-  expect_is(s$layers[[1]], "ggproto")
-  expect_is(s$layers[[1]]$geom, "GeomSf")
+  expect_s3_class(s$layers[[1]], "ggproto")
+  expect_s3_class(s$layers[[1]]$geom, "GeomSf")
   expect_equal(as.character(s$layers[[1]]$aes_params$fill), "white")
   expect_equal(as.character(s$layers[[1]]$aes_params$colour), "black")
   expect_equal(s$layers[[1]]$aes_params$linewidth, 0.4)
-  expect_is(s$layers[[2]], "ggproto")
-  expect_is(s$layers[[2]]$geom, "GeomText")
+  expect_s3_class(s$layers[[2]], "ggproto")
+  expect_s3_class(s$layers[[2]]$geom, "GeomText")
   expect_equal(deparse(s$layers[[2]]$mapping$label), "~.data$abbr")
   expect_equal(as.character(s$layers[[2]]$aes_params$colour), "blue")
 
-  expect_is(t$layers[[1]], "ggproto")
-  expect_is(s$layers[[1]]$geom, "GeomSf")
+  expect_s3_class(t$layers[[1]], "ggproto")
+  expect_s3_class(s$layers[[1]]$geom, "GeomSf")
   expect_equal(as.character(t$layers[[1]]$aes_params$fill), "yellow")
   expect_equal(as.character(t$layers[[1]]$aes_params$colour), "black")
   expect_equal(t$layers[[1]]$aes_params$linewidth, 0.6)
-  expect_is(t$layers[[2]], "ggproto")
-  expect_is(t$layers[[2]]$geom, "GeomText")
+  expect_s3_class(t$layers[[2]], "ggproto")
+  expect_s3_class(t$layers[[2]]$geom, "GeomText")
   expect_equal(deparse(t$layers[[2]]$mapping$label),
                "~sub(\" County\", \"\", .data$county)")
 
-  expect_is(u$layers[[1]], "ggproto")
-  expect_is(u$layers[[1]]$geom, "GeomSf")
+  expect_s3_class(u$layers[[1]], "ggproto")
+  expect_s3_class(u$layers[[1]]$geom, "GeomSf")
   expect_equal(as.character(u$layers[[1]]$aes_params$fill), "white")
   expect_equal(as.character(u$layers[[1]]$aes_params$colour), "black")
   expect_equal(u$layers[[1]]$aes_params$linewidth, 0.4)
-  expect_is(u$layers[[2]], "ggproto")
-  expect_is(u$layers[[2]]$geom, "GeomText")
+  expect_s3_class(u$layers[[2]], "ggproto")
+  expect_s3_class(u$layers[[2]]$geom, "GeomText")
   expect_equal(deparse(u$layers[[2]]$mapping$label), "~.data$abbr")
 
-  expect_is(v$layers[[1]], "ggproto")
-  expect_is(v$layers[[1]]$geom, "GeomSf")
+  expect_s3_class(v$layers[[1]], "ggproto")
+  expect_s3_class(v$layers[[1]]$geom, "GeomSf")
   expect_equal(as.character(v$layers[[1]]$aes_params$fill), "white")
   expect_equal(as.character(v$layers[[1]]$aes_params$colour), "black")
   expect_equal(v$layers[[1]]$aes_params$linewidth, 0.4)
-  expect_is(v$layers[[2]], "ggproto")
-  expect_is(v$layers[[2]]$geom, "GeomText")
+  expect_s3_class(v$layers[[2]], "ggproto")
+  expect_s3_class(v$layers[[2]]$geom, "GeomText")
   expect_equal(deparse(v$layers[[2]]$mapping$label), "~.data$abbr")
 })
 
